=============================
djorum
=============================

.. image:: https://badge.fury.io/py/djorum.png
    :target: https://badge.fury.io/py/djorum

.. image:: https://travis-ci.org/andrewblaney/djorum.png?branch=master
    :target: https://travis-ci.org/andrewblaney/djorum

.. image:: http://codecov.io/github/andrewblaney/djorum/coverage.svg?branch=master
    :target: http://codecov.io/github/andrewblaney/djorum?branch=master

Simple Django Forum

Documentation
-------------

The full documentation is at https://djorum.readthedocs.org

Quickstart
----------

Install djorum::

    pip install djorum

Then use it in a project::

    import djorum

Features
--------

* TODO

** Everyting.

Cookiecutter Tools Used in Making This Package
----------------------------------------------

*  cookiecutter
*  cookiecutter-djangopackage
